Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3088)

Unified Diff: chrome/browser/ui/search/toolbar_search_animator.h

Issue 10944016: Switch SearchTabHelper to use WebContentsUserData. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/search/toolbar_search_animator.h
diff --git a/chrome/browser/ui/search/toolbar_search_animator.h b/chrome/browser/ui/search/toolbar_search_animator.h
index 4ac90818590132b730dedeb843d5e914de36809f..6caa13fe36854cdf2fa51abac6cdc0d2ff2c3985 100644
--- a/chrome/browser/ui/search/toolbar_search_animator.h
+++ b/chrome/browser/ui/search/toolbar_search_animator.h
@@ -11,9 +11,12 @@
#include "chrome/browser/ui/search/search_types.h"
#include "ui/base/animation/animation_delegate.h"
-class TabContents;
class ToolbarModel;
+namespace content {
+class WebContents;
+}
+
namespace ui {
class MultiAnimation;
}
@@ -53,7 +56,7 @@ class ToolbarSearchAnimator : public SearchModelObserver,
// closing or detached, to jump to the end state of the animation.
// This allows a reactivated tab to show the end state of the animation,
// rather than the transient state.
- void FinishAnimation(TabContents* tab_contents);
+ void FinishAnimation(content::WebContents* web_contents);
// Add and remove observers.
void AddObserver(ToolbarSearchAnimatorObserver* observer);
@@ -81,9 +84,9 @@ class ToolbarSearchAnimator : public SearchModelObserver,
// ToolbarSearchAnimatorObserver::OnToolbarBackgroundAnimatorCanceled or
// ToolbarSearchAnimatorObserver::OnToolbarSeparatorAnimatorCanceled
// respectively.
// Pass in |tab_contents| if animation is canceled because of deactivating or
// detaching or closing a tab.
- void Reset(TabContents* tab_contents);
+ void Reset(content::WebContents* web_contents);
// Weak. Owned by Browser. Non-NULL.
SearchModel* search_model_;
@@ -81,9 +84,9 @@ class ToolbarSearchAnimator : public SearchModelObserver,
// ToolbarSearchAnimatorObserver::OnToolbarSeparatorAnimatorCanceled
// respectively.
- // Pass in |tab_contents| if animation is canceled because of deactivating or
+ // Pass in |web_contents| if animation is canceled because of deactivating or
// detaching or closing a tab.

Powered by Google App Engine
This is Rietveld 408576698